# 🀣 🅖🅟🅝 🅲🅻🅸🅴🅽🆃🆂 🀣

![Code Coverage](https://img.shields.io/badge/Coverage-90%25-green.svg)

ГПН Клиенты предоставляющие интерфейс для работы с источниками данных.

## Базовое использование

Конфигурация клиента на примере клиента NSI
